import { Client, GraphQLRequestParams } from '@urql/core';
import { z } from 'zod';

/** All built-in and custom scalars, mapped to their actual values */
type Scalars = {
    ID: string;
    String: string;
    Boolean: boolean;
    Int: number;
    Float: number;
    BigInt: any;
    DateTime: any;
    JSON: any;
    JSONObject: any;
};
/** Gas Prices for a given block. Gas values are returned in Wei. */
type CodegenGasPrice = {
    /** The average gas price */
    average: Scalars['Float'];
    /** The block number */
    blockNumber: Scalars['Int'];
    /** The highest gas price */
    ceiling: Scalars['Float'];
    /** The lowest gas price */
    floor: Scalars['Float'];
    /** The median gas price */
    median: Scalars['Float'];
    /** The total gas price */
    total: Scalars['Float'];
};
/** Marketplace where the token was sold */
type CodegenMarketplace = 'BLUR' | 'CRYPTOPUNKS' | 'LOOKSRARE' | 'NIFTY_GATEWAY' | 'OPENSEA' | 'SEAPORT' | 'X2Y2' | 'ZEROX';
type CodegenTokenTransferType = 'BURN' | 'MINT' | 'SALE' | 'SWAP' | 'TRANSFER';
type CodegenNftCollectionInfoFragment = {
    collection?: {
        address: string;
        baseTokenUri?: string | null;
        circulatingSupply?: any | null;
        description?: string | null;
        externalUrl?: string | null;
        name?: string | null;
        slug?: string | null;
        symbol?: string | null;
        totalSupply?: any | null;
        twitterUsername?: string | null;
        bannerImage?: Array<{
            height?: number | null;
            mimeType?: string | null;
            url: string;
            width?: number | null;
        }> | null;
        contract?: {
            address: string;
            isVerified?: boolean | null;
            name?: string | null;
            symbol?: string | null;
            supportedErcInterfaces?: Array<string> | null;
        } | null;
        image?: Array<{
            height?: number | null;
            mimeType?: string | null;
            url: string;
            width?: number | null;
        }> | null;
        ohlcvChart?: Array<{
            average?: number | null;
            close?: number | null;
            count: number;
            high?: number | null;
            low?: number | null;
            open?: number | null;
            volume?: number | null;
            timestamp: any;
        }> | null;
        openseaMetadata?: {
            isHidden?: boolean | null;
            isVerified?: boolean | null;
            unsafeSlug?: string | null;
        } | null;
    } | {
        address: string;
        baseTokenUri?: string | null;
        circulatingSupply?: any | null;
        description?: string | null;
        externalUrl?: string | null;
        name?: string | null;
        slug?: string | null;
        symbol?: string | null;
        totalSupply?: any | null;
        twitterUsername?: string | null;
        bannerImage?: Array<{
            height?: number | null;
            mimeType?: string | null;
            url: string;
            width?: number | null;
        }> | null;
        contract?: {
            address: string;
            isVerified?: boolean | null;
            name?: string | null;
            symbol?: string | null;
            supportedErcInterfaces?: Array<string> | null;
        } | null;
        image?: Array<{
            height?: number | null;
            mimeType?: string | null;
            url: string;
            width?: number | null;
        }> | null;
        ohlcvChart?: Array<{
            average?: number | null;
            close?: number | null;
            count: number;
            high?: number | null;
            low?: number | null;
            open?: number | null;
            volume?: number | null;
            timestamp: any;
        }> | null;
        openseaMetadata?: {
            isHidden?: boolean | null;
            isVerified?: boolean | null;
            unsafeSlug?: string | null;
        } | null;
    } | null;
};
type CodegenNftDetailsFragment = {
    nft?: {
        __typename: 'ERC721NFT';
        animationUrl?: string | null;
        collectionSlug?: string | null;
        contractAddress: string;
        description?: string | null;
        externalUrl?: string | null;
        metadata?: any | null;
        name?: string | null;
        tokenId: any;
        wallet?: {
            address: string;
            ensName?: string | null;
        } | null;
    } | {
        __typename: 'ERC1155NFT';
        animationUrl?: string | null;
        collectionSlug?: string | null;
        contractAddress: string;
        description?: string | null;
        externalUrl?: string | null;
        metadata?: any | null;
        name?: string | null;
        tokenId: any;
        wallets: {
            edges: Array<{
                node: {
                    address: string;
                    ensName?: string | null;
                };
            }>;
        };
    } | null;
};
type CodegenERC1155NFTNodeFragment = {
    __typename: 'ERC1155NFT';
    animationUrl?: string | null;
    collectionSlug?: string | null;
    contractAddress: string;
    description?: string | null;
    externalUrl?: string | null;
    metadata?: any | null;
    name?: string | null;
    tokenId: any;
    wallets: {
        edges: Array<{
            node: {
                address: string;
                ensName?: string | null;
            };
        }>;
    };
};
type CodegenERC721NFTNodeFragment = {
    __typename: 'ERC721NFT';
    animationUrl?: string | null;
    collectionSlug?: string | null;
    contractAddress: string;
    description?: string | null;
    externalUrl?: string | null;
    metadata?: any | null;
    name?: string | null;
    tokenId: any;
    attributes?: Array<{
        name: string;
        value: string;
    }> | null;
    wallet?: {
        address: string;
        ensName?: string | null;
    } | null;
};
type CodegenTransactionsNodeFragment = {
    blockNumber: number;
    blockTimestamp: any;
    contractAddress?: string | null;
    fromAddress: string;
    cumulativeGasUsed: any;
    effectiveGasPrice?: any | null;
    gas?: any | null;
    gasPrice?: any | null;
    gasUsed: any;
    hash: string;
    maxFeePerGas?: any | null;
    maxPriorityFeePerGas?: any | null;
    toAddress?: string | null;
    type?: string | null;
    input?: string | null;
    transactionIndex: number;
    value?: any | null;
};
type CodegenTrendingCollectionInfo_CodegenERC721Collection_CodegenFragment = {
    address: string;
    baseTokenUri?: string | null;
    circulatingSupply?: any | null;
    description?: string | null;
    externalUrl?: string | null;
    name?: string | null;
    symbol?: string | null;
    totalSupply?: any | null;
    twitterUsername?: string | null;
    image?: Array<{
        height?: number | null;
        mimeType?: string | null;
        url: string;
        width?: number | null;
    }> | null;
    openseaMetadata?: {
        isHidden?: boolean | null;
        isVerified?: boolean | null;
        unsafeSlug?: string | null;
    } | null;
};
type CodegenTrendingCollectionInfo_CodegenERC1155Collection_CodegenFragment = {
    address: string;
    baseTokenUri?: string | null;
    circulatingSupply?: any | null;
    description?: string | null;
    externalUrl?: string | null;
    name?: string | null;
    symbol?: string | null;
    totalSupply?: any | null;
    twitterUsername?: string | null;
    image?: Array<{
        height?: number | null;
        mimeType?: string | null;
        url: string;
        width?: number | null;
    }> | null;
    openseaMetadata?: {
        isHidden?: boolean | null;
        isVerified?: boolean | null;
        unsafeSlug?: string | null;
    } | null;
};
type CodegenTrendingCollectionInfoFragment = CodegenTrendingCollectionInfo_CodegenERC721Collection_CodegenFragment | CodegenTrendingCollectionInfo_CodegenERC1155Collection_CodegenFragment;
type CodegenWalletNFTNodeFragment = {
    nft?: {
        animationUrl?: string | null;
        collectionSlug?: string | null;
        contractAddress: string;
        description?: string | null;
        externalUrl?: string | null;
        metadata?: any | null;
        name?: string | null;
        tokenId: any;
    } | {
        animationUrl?: string | null;
        collectionSlug?: string | null;
        contractAddress: string;
        description?: string | null;
        externalUrl?: string | null;
        metadata?: any | null;
        name?: string | null;
        tokenId: any;
    } | null;
};
type CodegenContractInfo_CodegenNFTContract_CodegenFragment = {
    __typename: 'NFTContract';
    abi?: any | null;
    address: string;
    isVerified?: boolean | null;
    name?: string | null;
    supportedErcInterfaces?: Array<string> | null;
    symbol?: string | null;
};
type CodegenContractInfo_CodegenTokenContract_CodegenFragment = {
    __typename: 'TokenContract';
    decimals?: any | null;
    abi?: any | null;
    address: string;
    isVerified?: boolean | null;
    name?: string | null;
    supportedErcInterfaces?: Array<string> | null;
    symbol?: string | null;
};
type CodegenContractInfo_CodegenUnclassifiedContract_CodegenFragment = {
    __typename: 'UnclassifiedContract';
    abi?: any | null;
    address: string;
    isVerified?: boolean | null;
    name?: string | null;
    supportedErcInterfaces?: Array<string> | null;
    symbol?: string | null;
};
type CodegenContractInfoFragment = CodegenContractInfo_CodegenNFTContract_CodegenFragment | CodegenContractInfo_CodegenTokenContract_CodegenFragment | CodegenContractInfo_CodegenUnclassifiedContract_CodegenFragment;
type CodegenTokenBalanceNodeFragment = {
    totalBalance: any;
    contract?: {
        address: string;
        decimals?: any | null;
        name?: string | null;
        symbol?: string | null;
    } | null;
};
type CodegenTokenEventInfo_CodegenTokenBurnEvent_CodegenFragment = {
    __typename: 'TokenBurnEvent';
    tokenId?: any | null;
    tokenQuantity: any;
    blockNumber: number;
    fromAddress: string;
    timestamp: any;
    toAddress: string;
    transactionHash?: string | null;
    transferIndex: number;
    type: CodegenTokenTransferType;
};
type CodegenTokenEventInfo_CodegenTokenMintEvent_CodegenFragment = {
    __typename: 'TokenMintEvent';
    tokenQuantity: any;
    blockNumber: number;
    fromAddress: string;
    timestamp: any;
    toAddress: string;
    transactionHash?: string | null;
    transferIndex: number;
    type: CodegenTokenTransferType;
};
type CodegenTokenEventInfo_CodegenTokenSaleEvent_CodegenFragment = {
    __typename: 'TokenSaleEvent';
    marketplace?: CodegenMarketplace | null;
    receivedTokenContractAddress?: string | null;
    receivedTokenId?: any | null;
    sentTokenId?: any | null;
    blockNumber: number;
    fromAddress: string;
    timestamp: any;
    toAddress: string;
    transactionHash?: string | null;
    transferIndex: number;
    type: CodegenTokenTransferType;
};
type CodegenTokenEventInfo_CodegenTokenSwapEvent_CodegenFragment = {
    __typename: 'TokenSwapEvent';
    blockNumber: number;
    fromAddress: string;
    timestamp: any;
    toAddress: string;
    transactionHash?: string | null;
    transferIndex: number;
    type: CodegenTokenTransferType;
};
type CodegenTokenEventInfo_CodegenTokenTransferEvent_CodegenFragment = {
    __typename: 'TokenTransferEvent';
    tokenId?: any | null;
    contractAddress: string;
    tokenQuantity: any;
    blockNumber: number;
    fromAddress: string;
    timestamp: any;
    toAddress: string;
    transactionHash?: string | null;
    transferIndex: number;
    type: CodegenTokenTransferType;
};
type CodegenTokenEventInfoFragment = CodegenTokenEventInfo_CodegenTokenBurnEvent_CodegenFragment | CodegenTokenEventInfo_CodegenTokenMintEvent_CodegenFragment | CodegenTokenEventInfo_CodegenTokenSaleEvent_CodegenFragment | CodegenTokenEventInfo_CodegenTokenSwapEvent_CodegenFragment | CodegenTokenEventInfo_CodegenTokenTransferEvent_CodegenFragment;
type CodegenPaginationFragment = {
    endCursor?: string | null;
    hasNextPage: boolean;
    hasPreviousPage: boolean;
    startCursor?: string | null;
};

type ResultOutput = Record<string | number | symbol, any>;

declare class CustomUrqlClient {
    urqlClient: Client;
    constructor(urqlClient: Client);
    query<TVariables extends Record<string, unknown>, KResults extends Record<string, unknown>, KResultsOutput extends ResultOutput>(options: GraphQLRequestParams<any, TVariables>): Promise<{
        data: KResultsOutput | undefined;
    }>;
}

declare const supportedChains: readonly ["ethereum", "polygon", "ethereumSepolia"];
type ChainName = (typeof supportedChains)[number];

type SimplifyType<T> = T extends object ? {
    [K in keyof T]: SimplifyType<T[K]>;
} : T;

declare const walletByAddressValidator: z.ZodObject<{
    filter: z.ZodOptional<z.ZodObject<{
        contractTokens: z.ZodArray<z.ZodObject<{
            contractAddress: z.ZodString;
            tokenId: z.ZodOptional<z.ZodString>;
        }, "strict", z.ZodTypeAny, {
            contractAddress: string;
            tokenId?: string | undefined;
        }, {
            contractAddress: string;
            tokenId?: string | undefined;
        }>, "atleastone">;
    }, "strict", z.ZodTypeAny, {
        contractTokens: [{
            contractAddress: string;
            tokenId?: string | undefined;
        }, ...{
            contractAddress: string;
            tokenId?: string | undefined;
        }[]];
    }, {
        contractTokens: [{
            contractAddress: string;
            tokenId?: string | undefined;
        }, ...{
            contractAddress: string;
            tokenId?: string | undefined;
        }[]];
    }>>;
    before: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    after: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    first: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    address: z.ZodUnion<[z.ZodEffects<z.ZodString, string, string>, z.ZodString]>;
    chain: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ethereum", "polygon", "ethereumSepolia"]>>>;
}, "strict", z.ZodTypeAny, {
    address: string;
    filter?: {
        contractTokens: [{
            contractAddress: string;
            tokenId?: string | undefined;
        }, ...{
            contractAddress: string;
            tokenId?: string | undefined;
        }[]];
    } | undefined;
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}, {
    address: string;
    filter?: {
        contractTokens: [{
            contractAddress: string;
            tokenId?: string | undefined;
        }, ...{
            contractAddress: string;
            tokenId?: string | undefined;
        }[]];
    } | undefined;
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}>;
type WalletNFTsByAddressInput = z.infer<typeof walletByAddressValidator>;
type WalletNFTsByAddressResult = SimplifyType<{
    address: string;
    ensName: string;
    results: CodegenWalletNFTNodeFragment['nft'][];
    pageInfo: CodegenPaginationFragment;
}>;

declare const nftDetailsValidator: z.ZodObject<{
    contractAddress: z.ZodString;
    tokenId: z.ZodString;
    chain: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ethereum", "polygon", "ethereumSepolia"]>>>;
}, "strict", z.ZodTypeAny, {
    contractAddress: string;
    tokenId: string;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}, {
    contractAddress: string;
    tokenId: string;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}>;
type NFTDetailsInput = z.infer<typeof nftDetailsValidator>;
type NFTDetailsResult = SimplifyType<{
    nft: CodegenNftDetailsFragment['nft'];
}>;

declare const nftCollectionDetailsValidator: z.ZodObject<{
    contractAddress: z.ZodString;
    chain: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ethereum", "polygon", "ethereumSepolia"]>>>;
}, "strict", z.ZodTypeAny, {
    contractAddress: string;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}, {
    contractAddress: string;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}>;
type NftCollectionDetailsInput = z.infer<typeof nftCollectionDetailsValidator>;
type NftCollectionDetailsResult = SimplifyType<{
    collection: CodegenNftCollectionInfoFragment['collection'];
}>;

declare const nftTrendingCollectionsValidator: z.ZodObject<{
    before: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    after: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    first: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    chain: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ethereum", "polygon", "ethereumSepolia"]>>>;
}, "strict", z.ZodTypeAny, {
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}, {
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}>;
type NFTTrendingCollectionsInput = z.infer<typeof nftTrendingCollectionsValidator>;
type NFTTrendingCollectionResult = SimplifyType<{
    results: CodegenTrendingCollectionInfoFragment[];
    pageInfo: CodegenPaginationFragment;
}>;

type NftErcStandards = 'ERC721' | 'ERC1155';

declare const nftsByContractAddressValidator: z.ZodObject<{
    contractAddress: z.ZodString;
    before: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    after: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    first: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    chain: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ethereum", "polygon", "ethereumSepolia"]>>>;
}, "strict", z.ZodTypeAny, {
    contractAddress: string;
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}, {
    contractAddress: string;
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}>;
type NFTsByContractAddressInput = z.infer<typeof nftsByContractAddressValidator>;
type NFTsByContractAddressResult = SimplifyType<{
    standard: NftErcStandards | null;
    results: [CodegenERC721NFTNodeFragment | CodegenERC1155NFTNodeFragment][];
    pageInfo: CodegenPaginationFragment;
}>;

declare const verifyOwnershipValidator: z.ZodObject<{
    address: z.ZodUnion<[z.ZodEffects<z.ZodString, string, string>, z.ZodString]>;
    nfts: z.ZodArray<z.ZodObject<{
        contractAddress: z.ZodString;
        tokenId: z.ZodOptional<z.ZodString>;
    }, "strict", z.ZodTypeAny, {
        contractAddress: string;
        tokenId?: string | undefined;
    }, {
        contractAddress: string;
        tokenId?: string | undefined;
    }>, "atleastone">;
    chain: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ethereum", "polygon", "ethereumSepolia"]>>>;
}, "strict", z.ZodTypeAny, {
    address: string;
    nfts: [{
        contractAddress: string;
        tokenId?: string | undefined;
    }, ...{
        contractAddress: string;
        tokenId?: string | undefined;
    }[]];
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}, {
    address: string;
    nfts: [{
        contractAddress: string;
        tokenId?: string | undefined;
    }, ...{
        contractAddress: string;
        tokenId?: string | undefined;
    }[]];
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}>;
type VerifyOwnershipByAddressInput = z.infer<typeof verifyOwnershipValidator>;

declare class NftsController {
    private client;
    private defaultChain;
    constructor(client: CustomUrqlClient, defaultChain?: ChainName);
    getByWallet(variables: WalletNFTsByAddressInput): Promise<WalletNFTsByAddressResult>;
    private getByWalletENS;
    private getByWalletAddress;
    getTrendingCollections(variables: NFTTrendingCollectionsInput): Promise<NFTTrendingCollectionResult>;
    getByContractAddress(variables: NFTsByContractAddressInput): Promise<NFTsByContractAddressResult>;
    getNFTDetails(variables: NFTDetailsInput): Promise<NFTDetailsResult>;
    getCollectionDetails(variables: NftCollectionDetailsInput): Promise<NftCollectionDetailsResult>;
    verifyOwnership(variables: VerifyOwnershipByAddressInput): Promise<boolean>;
    private verifyOwnershipByAddress;
    private verifyOwnershipByENS;
}

type BalancesByWalletENSResult = SimplifyType<{
    address: string;
    ensName: string;
    results: CodegenTokenBalanceNodeFragment[];
    pageInfo: CodegenPaginationFragment;
}>;

declare const balancesByWalletAddressValidator$1: z.ZodObject<{
    before: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    after: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    first: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    address: z.ZodUnion<[z.ZodEffects<z.ZodString, string, string>, z.ZodString]>;
    chain: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ethereum", "polygon", "ethereumSepolia"]>>>;
}, "strict", z.ZodTypeAny, {
    address: string;
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}, {
    address: string;
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}>;
type BalancesByWalletAddressInput = z.infer<typeof balancesByWalletAddressValidator$1>;

declare class TokensController {
    private client;
    private defaultChain;
    constructor(client: CustomUrqlClient, defaultChain?: ChainName);
    getBalancesByWallet(variables: BalancesByWalletAddressInput): Promise<BalancesByWalletENSResult>;
    private getBalancesByWalletENS;
    private getBalancesByWalletAddress;
    private flattenBalanceResponses;
}

declare const gasPricesValidator: z.ZodObject<{
    filter: z.ZodOptional<z.ZodNullable<z.ZodObject<{
        blockNumber: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            gt: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            gte: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodNumber, "many">>>;
            lt: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            lte: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodNumber, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        }, {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        }>>>;
    }, "strict", z.ZodTypeAny, {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
    }, {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
    }>>>;
    returnInGwei: z.ZodOptional<z.ZodNullable<z.ZodBoolean>>;
    chain: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ethereum", "polygon", "ethereumSepolia"]>>>;
}, "strict", z.ZodTypeAny, {
    filter?: {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
    } | null | undefined;
    returnInGwei?: boolean | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}, {
    filter?: {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
    } | null | undefined;
    returnInGwei?: boolean | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}>;
type GasPricesInput = z.infer<typeof gasPricesValidator>;
type GasPricesResult = SimplifyType<{
    gasPrices: CodegenGasPrice[];
}>;

declare class UtilsController {
    private client;
    private defaultChain;
    constructor(client: CustomUrqlClient, defaultChain?: ChainName);
    getGasPrices(variables: GasPricesInput): Promise<GasPricesResult>;
}

declare const contractDetailsValidator: z.ZodObject<{
    contractAddress: z.ZodString;
    chain: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ethereum", "polygon", "ethereumSepolia"]>>>;
}, "strict", z.ZodTypeAny, {
    contractAddress: string;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}, {
    contractAddress: string;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}>;
type ContractDetailsInput = z.infer<typeof contractDetailsValidator>;
type ContractDetailsResult = SimplifyType<{
    contract: CodegenContractInfoFragment | null;
}>;

declare class ContractsController {
    private client;
    private defaultChain;
    constructor(client: CustomUrqlClient, defaultChain?: ChainName);
    getDetails(variables: ContractDetailsInput): Promise<ContractDetailsResult>;
}

declare const contractEventsValidator: z.ZodObject<{
    contractAddress: z.ZodString;
    filter: z.ZodOptional<z.ZodNullable<z.ZodObject<{
        blockNumber: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            gt: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            gte: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodNumber, "many">>>;
            lt: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            lte: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodNumber, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        }, {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        }>>>;
        contractAddress: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        contractStandard: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ERC20", "ERC721", "ERC1155"]>>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["ERC20", "ERC721", "ERC1155"]>, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["ERC20", "ERC721", "ERC1155"]>, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        }, {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        }>>>;
        fromAddress: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        marketplace: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodEnum<["BLUR", "CRYPTOPUNKS", "LOOKSRARE", "NIFTY_GATEWAY", "OPENSEA", "SEAPORT", "X2Y2", "ZEROX"]>>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["BLUR", "CRYPTOPUNKS", "LOOKSRARE", "NIFTY_GATEWAY", "OPENSEA", "SEAPORT", "X2Y2", "ZEROX"]>, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["BLUR", "CRYPTOPUNKS", "LOOKSRARE", "NIFTY_GATEWAY", "OPENSEA", "SEAPORT", "X2Y2", "ZEROX"]>, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        }, {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        }>>>;
        timestamp: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            gt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            gte: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            lt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            lte: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        toAddress: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        transactionHash: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        type: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodEnum<["TRANSFER", "MINT", "SALE", "SWAP", "BURN"]>>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["TRANSFER", "MINT", "SALE", "SWAP", "BURN"]>, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["TRANSFER", "MINT", "SALE", "SWAP", "BURN"]>, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        }, {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        }>>>;
        walletAddress: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
    }, "strict", z.ZodTypeAny, {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        contractAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        contractStandard?: {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        } | null | undefined;
        fromAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        marketplace?: {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        } | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        transactionHash?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        type?: {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        } | null | undefined;
        walletAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
    }, {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        contractAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        contractStandard?: {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        } | null | undefined;
        fromAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        marketplace?: {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        } | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        transactionHash?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        type?: {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        } | null | undefined;
        walletAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
    }>>>;
    before: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    after: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    first: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    chain: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ethereum", "polygon", "ethereumSepolia"]>>>;
}, "strict", z.ZodTypeAny, {
    contractAddress: string;
    filter?: {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        contractAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        contractStandard?: {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        } | null | undefined;
        fromAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        marketplace?: {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        } | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        transactionHash?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        type?: {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        } | null | undefined;
        walletAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
    } | null | undefined;
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}, {
    contractAddress: string;
    filter?: {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        contractAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        contractStandard?: {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        } | null | undefined;
        fromAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        marketplace?: {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        } | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        transactionHash?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        type?: {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        } | null | undefined;
        walletAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
    } | null | undefined;
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}>;
type ContractEventsInput = z.infer<typeof contractEventsValidator>;
type ContractEventsResult = SimplifyType<{
    results: CodegenTokenEventInfoFragment[];
    pageInfo: CodegenPaginationFragment;
}>;

declare const collectionEventsValidator: z.ZodObject<{
    contractAddress: z.ZodString;
    filter: z.ZodOptional<z.ZodNullable<z.ZodObject<{
        blockNumber: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            gt: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            gte: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodNumber, "many">>>;
            lt: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            lte: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodNumber, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        }, {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        }>>>;
        contractAddress: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        contractStandard: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ERC20", "ERC721", "ERC1155"]>>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["ERC20", "ERC721", "ERC1155"]>, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["ERC20", "ERC721", "ERC1155"]>, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        }, {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        }>>>;
        fromAddress: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        marketplace: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodEnum<["BLUR", "CRYPTOPUNKS", "LOOKSRARE", "NIFTY_GATEWAY", "OPENSEA", "SEAPORT", "X2Y2", "ZEROX"]>>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["BLUR", "CRYPTOPUNKS", "LOOKSRARE", "NIFTY_GATEWAY", "OPENSEA", "SEAPORT", "X2Y2", "ZEROX"]>, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["BLUR", "CRYPTOPUNKS", "LOOKSRARE", "NIFTY_GATEWAY", "OPENSEA", "SEAPORT", "X2Y2", "ZEROX"]>, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        }, {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        }>>>;
        timestamp: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            gt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            gte: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            lt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            lte: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        toAddress: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        transactionHash: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        type: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodEnum<["TRANSFER", "MINT", "SALE", "SWAP", "BURN"]>>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["TRANSFER", "MINT", "SALE", "SWAP", "BURN"]>, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["TRANSFER", "MINT", "SALE", "SWAP", "BURN"]>, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        }, {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        }>>>;
        walletAddress: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
    }, "strict", z.ZodTypeAny, {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        contractAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        contractStandard?: {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        } | null | undefined;
        fromAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        marketplace?: {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        } | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        transactionHash?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        type?: {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        } | null | undefined;
        walletAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
    }, {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        contractAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        contractStandard?: {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        } | null | undefined;
        fromAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        marketplace?: {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        } | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        transactionHash?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        type?: {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        } | null | undefined;
        walletAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
    }>>>;
    before: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    after: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    first: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    chain: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ethereum", "polygon", "ethereumSepolia"]>>>;
}, "strict", z.ZodTypeAny, {
    contractAddress: string;
    filter?: {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        contractAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        contractStandard?: {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        } | null | undefined;
        fromAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        marketplace?: {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        } | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        transactionHash?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        type?: {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        } | null | undefined;
        walletAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
    } | null | undefined;
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}, {
    contractAddress: string;
    filter?: {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        contractAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        contractStandard?: {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        } | null | undefined;
        fromAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        marketplace?: {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        } | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        transactionHash?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        type?: {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        } | null | undefined;
        walletAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
    } | null | undefined;
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}>;
type CollectionEventsInput = z.infer<typeof collectionEventsValidator>;
type CollectionEventsResult = SimplifyType<{
    results: CodegenTokenEventInfoFragment[];
    pageInfo: CodegenPaginationFragment;
}>;

declare const nftEventsValidator: z.ZodObject<{
    contractAddress: z.ZodString;
    filter: z.ZodOptional<z.ZodNullable<z.ZodObject<{
        blockNumber: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            gt: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            gte: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodNumber, "many">>>;
            lt: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            lte: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodNumber, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        }, {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        }>>>;
        contractAddress: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        contractStandard: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ERC20", "ERC721", "ERC1155"]>>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["ERC20", "ERC721", "ERC1155"]>, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["ERC20", "ERC721", "ERC1155"]>, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        }, {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        }>>>;
        fromAddress: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        marketplace: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodEnum<["BLUR", "CRYPTOPUNKS", "LOOKSRARE", "NIFTY_GATEWAY", "OPENSEA", "SEAPORT", "X2Y2", "ZEROX"]>>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["BLUR", "CRYPTOPUNKS", "LOOKSRARE", "NIFTY_GATEWAY", "OPENSEA", "SEAPORT", "X2Y2", "ZEROX"]>, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["BLUR", "CRYPTOPUNKS", "LOOKSRARE", "NIFTY_GATEWAY", "OPENSEA", "SEAPORT", "X2Y2", "ZEROX"]>, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        }, {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        }>>>;
        timestamp: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            gt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            gte: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            lt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            lte: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        toAddress: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        transactionHash: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        type: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodEnum<["TRANSFER", "MINT", "SALE", "SWAP", "BURN"]>>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["TRANSFER", "MINT", "SALE", "SWAP", "BURN"]>, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["TRANSFER", "MINT", "SALE", "SWAP", "BURN"]>, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        }, {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        }>>>;
        walletAddress: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
    }, "strict", z.ZodTypeAny, {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        contractAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        contractStandard?: {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        } | null | undefined;
        fromAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        marketplace?: {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        } | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        transactionHash?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        type?: {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        } | null | undefined;
        walletAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
    }, {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        contractAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        contractStandard?: {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        } | null | undefined;
        fromAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        marketplace?: {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        } | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        transactionHash?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        type?: {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        } | null | undefined;
        walletAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
    }>>>;
    before: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    after: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    first: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    tokenId: z.ZodString;
    chain: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ethereum", "polygon", "ethereumSepolia"]>>>;
}, "strict", z.ZodTypeAny, {
    contractAddress: string;
    tokenId: string;
    filter?: {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        contractAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        contractStandard?: {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        } | null | undefined;
        fromAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        marketplace?: {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        } | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        transactionHash?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        type?: {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        } | null | undefined;
        walletAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
    } | null | undefined;
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}, {
    contractAddress: string;
    tokenId: string;
    filter?: {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        contractAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        contractStandard?: {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        } | null | undefined;
        fromAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        marketplace?: {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        } | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        transactionHash?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        type?: {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        } | null | undefined;
        walletAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
    } | null | undefined;
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}>;
type NFTEventsInput = z.infer<typeof nftEventsValidator>;
type NFTEventsResult = SimplifyType<{
    results: CodegenTokenEventInfoFragment[];
    pageInfo: CodegenPaginationFragment;
}>;

declare const allEventsValidator: z.ZodObject<{
    filter: z.ZodOptional<z.ZodNullable<z.ZodObject<{
        blockNumber: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            gt: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            gte: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodNumber, "many">>>;
            lt: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            lte: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodNumber, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        }, {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        }>>>;
        contractAddress: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        contractStandard: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ERC20", "ERC721", "ERC1155"]>>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["ERC20", "ERC721", "ERC1155"]>, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["ERC20", "ERC721", "ERC1155"]>, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        }, {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        }>>>;
        fromAddress: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        marketplace: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodEnum<["BLUR", "CRYPTOPUNKS", "LOOKSRARE", "NIFTY_GATEWAY", "OPENSEA", "SEAPORT", "X2Y2", "ZEROX"]>>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["BLUR", "CRYPTOPUNKS", "LOOKSRARE", "NIFTY_GATEWAY", "OPENSEA", "SEAPORT", "X2Y2", "ZEROX"]>, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["BLUR", "CRYPTOPUNKS", "LOOKSRARE", "NIFTY_GATEWAY", "OPENSEA", "SEAPORT", "X2Y2", "ZEROX"]>, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        }, {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        }>>>;
        timestamp: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            gt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            gte: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            lt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            lte: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        toAddress: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        transactionHash: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        type: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodEnum<["TRANSFER", "MINT", "SALE", "SWAP", "BURN"]>>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["TRANSFER", "MINT", "SALE", "SWAP", "BURN"]>, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodEnum<["TRANSFER", "MINT", "SALE", "SWAP", "BURN"]>, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        }, {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        }>>>;
        walletAddress: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
    }, "strict", z.ZodTypeAny, {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        contractAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        contractStandard?: {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        } | null | undefined;
        fromAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        marketplace?: {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        } | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        transactionHash?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        type?: {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        } | null | undefined;
        walletAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
    }, {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        contractAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        contractStandard?: {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        } | null | undefined;
        fromAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        marketplace?: {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        } | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        transactionHash?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        type?: {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        } | null | undefined;
        walletAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
    }>>>;
    before: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    after: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    first: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    chain: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ethereum", "polygon", "ethereumSepolia"]>>>;
}, "strict", z.ZodTypeAny, {
    filter?: {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        contractAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        contractStandard?: {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        } | null | undefined;
        fromAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        marketplace?: {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        } | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        transactionHash?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        type?: {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        } | null | undefined;
        walletAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
    } | null | undefined;
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}, {
    filter?: {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        contractAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        contractStandard?: {
            eq?: "ERC721" | "ERC1155" | "ERC20" | null | undefined;
            in?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
            notIn?: ("ERC721" | "ERC1155" | "ERC20")[] | null | undefined;
        } | null | undefined;
        fromAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        marketplace?: {
            eq?: "BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX" | null | undefined;
            in?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
            notIn?: ("BLUR" | "CRYPTOPUNKS" | "LOOKSRARE" | "NIFTY_GATEWAY" | "OPENSEA" | "SEAPORT" | "X2Y2" | "ZEROX")[] | null | undefined;
        } | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        transactionHash?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        type?: {
            eq?: "BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER" | null | undefined;
            in?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
            notIn?: ("BURN" | "MINT" | "SALE" | "SWAP" | "TRANSFER")[] | null | undefined;
        } | null | undefined;
        walletAddress?: {
            eq?: string | null | undefined;
            in?: string[] | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
    } | null | undefined;
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}>;
type AllEventsInput = z.infer<typeof allEventsValidator>;
type AllEventsResult = SimplifyType<{
    results: CodegenTokenEventInfoFragment[];
    pageInfo: CodegenPaginationFragment;
}>;

declare class EventsController {
    private client;
    private defaultChain;
    constructor(client: CustomUrqlClient, defaultChain?: ChainName);
    getByContract(variables: ContractEventsInput): Promise<ContractEventsResult>;
    getByNFTCollection(variables: CollectionEventsInput): Promise<CollectionEventsResult>;
    getByNFT(variables: NFTEventsInput): Promise<NFTEventsResult>;
    getAll(variables: AllEventsInput): Promise<AllEventsResult>;
}

declare const balancesByWalletAddressValidator: z.ZodObject<{
    before: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    after: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    first: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    address: z.ZodUnion<[z.ZodEffects<z.ZodString, string, string>, z.ZodString]>;
    chain: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ethereum", "polygon", "ethereumSepolia"]>>>;
}, "strict", z.ZodTypeAny, {
    address: string;
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}, {
    address: string;
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}>;
type TransactionsByWalletAddressInput = z.infer<typeof balancesByWalletAddressValidator>;
type TransactionsByWalletAddressResult = SimplifyType<{
    address: string;
    ensName: string;
    results: CodegenTransactionsNodeFragment[];
    pageInfo: CodegenPaginationFragment;
}>;

declare const transactionsBySearchValidator: z.ZodObject<{
    filter: z.ZodOptional<z.ZodObject<{
        blockNumber: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            gt: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            gte: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodNumber, "many">>>;
            lt: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            lte: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodNumber, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        }, {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        }>>>;
        fromAddress: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        timestamp: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            eq: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            gt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            gte: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            in: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
            lt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            lte: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            notIn: z.ZodOptional<z.ZodNullable<z.ZodArray<z.ZodString, "many">>>;
        }, "strict", z.ZodTypeAny, {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        }, {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        }>>>;
        toAddress: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    }, "strict", z.ZodTypeAny, {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        fromAddress?: string | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: string | null | undefined;
    }, {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        fromAddress?: string | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: string | null | undefined;
    }>>;
    before: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    after: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    first: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    chain: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ethereum", "polygon", "ethereumSepolia"]>>>;
}, "strict", z.ZodTypeAny, {
    filter?: {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        fromAddress?: string | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: string | null | undefined;
    } | undefined;
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}, {
    filter?: {
        blockNumber?: {
            eq?: number | null | undefined;
            gt?: number | null | undefined;
            gte?: number | null | undefined;
            in?: number[] | null | undefined;
            lt?: number | null | undefined;
            lte?: number | null | undefined;
            notIn?: number[] | null | undefined;
        } | null | undefined;
        fromAddress?: string | null | undefined;
        timestamp?: {
            eq?: string | null | undefined;
            gt?: string | null | undefined;
            gte?: string | null | undefined;
            in?: string[] | null | undefined;
            lt?: string | null | undefined;
            lte?: string | null | undefined;
            notIn?: string[] | null | undefined;
        } | null | undefined;
        toAddress?: string | null | undefined;
    } | undefined;
    before?: string | null | undefined;
    after?: string | null | undefined;
    first?: number | null | undefined;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}>;
type TransactionsBySearchInput = z.infer<typeof transactionsBySearchValidator>;
type TransactionsBySearchResult = SimplifyType<{
    results: CodegenTransactionsNodeFragment[];
    pageInfo: CodegenPaginationFragment;
}>;

declare const transactionsByHashValidator: z.ZodObject<{
    hash: z.ZodString;
    chain: z.ZodOptional<z.ZodNullable<z.ZodEnum<["ethereum", "polygon", "ethereumSepolia"]>>>;
}, "strict", z.ZodTypeAny, {
    hash: string;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}, {
    hash: string;
    chain?: "ethereum" | "polygon" | "ethereumSepolia" | null | undefined;
}>;
type TransactionsByHashInput = z.infer<typeof transactionsByHashValidator>;
type TransactionsByHashResult = SimplifyType<{
    transaction: CodegenTransactionsNodeFragment | null;
}>;

declare class TransactionsController {
    private client;
    private defaultChain;
    constructor(client: CustomUrqlClient, defaultChain?: ChainName);
    getByWallet(variables: TransactionsByWalletAddressInput): Promise<TransactionsByWalletAddressResult>;
    private getByWalletAddress;
    private getByWalletENS;
    getAll(variables: TransactionsBySearchInput): Promise<TransactionsBySearchResult>;
    getByHash(variables: TransactionsByHashInput): Promise<TransactionsByHashResult>;
}

interface ApiArguments {
    graphApiKey?: string;
    additionalHeaders?: Record<string, string>;
    defaultChain?: ChainName;
}
declare class API {
    readonly urqlClient: Client;
    private customUrqlClient;
    private graphApiKey?;
    private additionalHeaders?;
    readonly defaultChain: ChainName;
    readonly nfts: NftsController;
    readonly tokens: TokensController;
    readonly utils: UtilsController;
    readonly contracts: ContractsController;
    readonly transactions: TransactionsController;
    readonly events: EventsController;
    readonly graphApiClient: Client;
    constructor({ graphApiKey, additionalHeaders, defaultChain, }?: ApiArguments);
    private createUrqlClient;
}

export { API as default };
